chordtools.change_defective_chord_to_note_or_rest
=================================================

.. autofunction:: abjad.tools.chordtools.change_defective_chord_to_note_or_rest.change_defective_chord_to_note_or_rest
